@@ -13,10 +13,12 @@ from typing import Union
 from datetime import datetime
 import numpy as np
 import pandas as pd
-from meteostat.core.cache import get_file_path, file_in_cache
+from meteostat.core.cache import get_local_file_path, file_in_cache
+from meteostat.enumerations.granularity import Granularity
 from meteostat.core.loader import processing_handler, load_handler
 from meteostat.core.warn import warn
 from meteostat.utilities.aggregations import weighted_average
+from meteostat.utilities.endpoint import generate_endpoint_path
 from meteostat.interface.base import Base
 from meteostat.interface.point import Point
 
@@ -78,10 +80,13 @@ class Normals(Base):
         """
 
         # File name
-        file = f'normals/{station}.csv.gz'
+        file = generate_endpoint_path(
+            Granularity.NORMALS,
+            station
+        )
 
         # Get local file path
-        path = get_file_path(self.cache_dir, self.cache_subdir, file)
+        path = get_local_file_path(self.cache_dir, self.cache_subdir, file)
 
         # Check if file in cache
         if self.max_age > 0 and file_in_cache(path, self.max_age):
@@ -97,11 +102,13 @@ class Normals(Base):
                 file,
                 self._columns,
                 self._types,
-                None)
+                None
+            )
 
             if df.index.size > 0:
 
                 # Add weather station ID
+                # pylint: disable=unsupported-assignment-operation
                 df['station'] = station
 
                 # Set index
@@ -130,12 +137,7 @@ class Normals(Base):
         if len(self._stations) > 0:
 
             # List of datasets
-            datasets = []
-
-            for station in self._stations:
-                datasets.append((
-                    str(station),
-                ))
+            datasets = [(str(station),) for station in self._stations]
 
             # Data Processing
             return processing_handler(
